# remirepo spec file for php-pecl-datadog-trace
#
# Copyright (c) 2019 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%if 0%{?scl:1}
%global sub_prefix %{scl_prefix}
%scl_package       php-pecl-datadog-trace
%else
%global _root_libdir %{_libdir}
%endif

# pecl name
%global proj_name  datadog_trace
# no underscore for package name
%global safe_name  datadog-trace
# extension name
%global pecl_name  ddtrace

%if "%{php_version}" > "5.6"
%global with_zts   0%{!?_without_zts:%{?__ztsphp:1}}
%else
%global with_zts   0
%endif
%global with_tests 0%{!?_without_tests:1}
%if "%{php_version}" < "5.6"
%global ini_name   %{pecl_name}.ini
%else
%global ini_name   40-%{pecl_name}.ini
%endif

Summary:        APM and distributed tracing for PHP
Name:           %{?sub_prefix}php-pecl-datadog-trace
Version:        0.35.0
Release:        1%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:        MIT
URL:            http://pecl.php.net/package/%{proj_name}
Source0:        http://pecl.php.net/get/%{proj_name}-%{version}.tgz

%if 0%{?rhel} == 6
BuildRequires:  devtoolset-6-toolchain
%else
BuildRequires:  %{?dtsprefix}gcc
%endif
BuildRequires:  %{?scl_prefix}php-devel
BuildRequires:  %{?scl_prefix}php-pear
BuildRequires:  curl-devel
# For tests
BuildRequires:  %{?scl_prefix}php-curl
BuildRequires:  %{?scl_prefix}php-json
BuildRequires:  %{?scl_prefix}php-posix

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}
%{?_sclreq:Requires: %{?scl_prefix}runtime%{?_sclreq}%{?_isa}}

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{proj_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{proj_name})%{?_isa} = %{version}
%if "%{?scl_prefix}" != "%{?sub_prefix}"
Provides:       %{?scl_prefix}php-pecl-%{safe_name}          = %{version}-%{release}
Provides:       %{?scl_prefix}php-pecl-%{safe_name}%{?_isa}  = %{version}-%{release}
%endif

%if "%{?vendor}" == "Remi Collet" && 0%{!?scl:1} && 0%{?rhel}
# Other third party repo stuff
%if "%{php_version}" > "7.1"
Obsoletes:     php71u-pecl-%{safe_name} <= %{version}
Obsoletes:     php71w-pecl-%{safe_name} <= %{version}
%endif
%if "%{php_version}" > "7.2"
Obsoletes:     php72u-pecl-%{safe_name} <= %{version}
Obsoletes:     php72w-pecl-%{safe_name} <= %{version}
%endif
%if "%{php_version}" > "7.3"
Obsoletes:     php73-pecl-%{safe_name}  <= %{version}
Obsoletes:     php73w-pecl-%{safe_name} <= %{version}
%endif
%if "%{php_version}" > "7.4"
Obsoletes:     php74-pecl-%{safe_name}  <= %{version}
Obsoletes:     php74w-pecl-%{safe_name} <= %{version}
%endif
%endif

%if 0%{?fedora} < 20 && 0%{?rhel} < 7
# Filter shared private
%{?filter_provides_in: %filter_provides_in %{_libdir}/.*\.so$}
%{?filter_setup}
%endif


%description
The Datadog PHP Tracer brings APM and distributed tracing to PHP.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c
mv %{proj_name}-%{version} NTS

# Don't install tests
sed -e 's/role="test"/role="src"/' \
    %{?_licensedir:-e '/LICENSE/s/role="doc"/role="src"/' } \
    -i package.xml

cd NTS
cp src/ext/mpack/LICENSE LICENSE.mpack
: Sanity check, really often broken
extver=$(sed -n '/#define PHP_DDTRACE_VERSION /{s/.* "//;s/".*$//;p}' src/ext/version.h)
if test "x${extver}" != "x%{version}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}.
   exit 1
fi
cd ..

%if %{with_zts}
# Duplicate source tree for NTS / ZTS build
cp -pr NTS ZTS
%endif

# Create configuration file
cat << 'EOF' | tee %{ini_name}
; Enable %{pecl_name} extension module
extension=%{pecl_name}.so

; Configuration
;ddtrace.disable = Off
;ddtrace.internal_blacklisted_modules_list = 'ionCube Loader,'
;ddtrace.request_init_hook = ''
;ddtrace.strict_mode = Off
EOF


%build
%if 0%{?rhel} == 6
source /opt/rh/devtoolset-6/enable
%endif
%{?dtsenable}

cd NTS
%{_bindir}/phpize
%configure \
    --enable-ddtrace \
    --with-php-config=%{_bindir}/php-config
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%{_bindir}/zts-phpize
%configure \
    --enable-ddtrace \
    --with-php-config=%{_bindir}/zts-php-config
make %{?_smp_mflags}
%endif


%install
%if 0%{?rhel} == 6
source /opt/rh/devtoolset-6/enable
%endif
%{?dtsenable}

make -C NTS install INSTALL_ROOT=%{buildroot}

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 NTS/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
# Erratic results
rm ?TS/tests/ext/segfault_backtrace_*.phpt
%if %{__isa_bits} < 64
# see https://github.com/DataDog/dd-trace-php/issues/394
rm ?TS/tests/ext/dd_trace_coms_test_parallel_writer_consistency.phpt
rm ?TS/tests/ext/circuit_breaker_info.phpt
rm ?TS/tests/ext/sandbox/dd_trace_function_complex.phpt
rm ?TS/tests/ext/sandbox/dd_trace_function_internal.phpt
rm ?TS/tests/ext/sandbox/dd_trace_function_userland.phpt
rm ?TS/tests/ext/sandbox/dd_trace_method.phpt
rm ?TS/tests/ext/sandbox/dd_trace_method_works_with_dd_trace.phpt
rm ?TS/tests/ext/sandbox/errors_are_flagged_from_userland.phpt
rm ?TS/tests/ext/sandbox/exceptions_and_errors_are_ignored_in_tracing_closure.phpt
rm ?TS/tests/ext/sandbox/dd_trace_set_trace_id.phpt
%endif


MOD="-n"
[ -f %{php_extdir}/curl.so ]  && MOD="$MOD -d extension=curl.so"
[ -f %{php_extdir}/json.so ]  && MOD="$MOD -d extension=json.so"
[ -f %{php_extdir}/posix.so ] && MOD="$MOD -d extension=posix.so"

cd NTS
: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep -i %{pecl_name}

: Upstream test suite for NTS extension
TEST_PHP_EXECUTABLE=%{_bindir}/php \
TEST_PHP_ARGS="$MOD -d extension=$PWD/modules/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{_bindir}/php -n run-tests.php -q --show-diff

%if %{with_zts}
cd ../ZTS
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep -i %{pecl_name}

: Upstream test suite for ZTS extension
TEST_PHP_EXECUTABLE=%{__ztsphp} \
TEST_PHP_ARGS="$MOD -d extension=$PWD/modules/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__ztsphp} -n run-tests.php -q --show-diff
%endif


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{proj_name} >/dev/null || :
fi
%endif


%files
%doc %{pecl_docdir}/%{pecl_name}
%{?_licensedir:%license NTS/LICENSE*}

%{pecl_xmldir}/%{name}.xml
%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Fri Dec  6 2019 Remi Collet <remi@remirepo.net> - 0.35.0-1
- update to 0.35.0

* Tue Nov 12 2019 Remi Collet <remi@remirepo.net> - 0.34.1-1
- update to 0.34.1

* Wed Oct 30 2019 Remi Collet <remi@remirepo.net> - 0.34.0-1
- update to 0.34.0

* Thu Oct 17 2019 Remi Collet <remi@remirepo.net> - 0.33.0-1
- update to 0.33.0 (no change)

* Thu Oct 10 2019 Remi Collet <remi@remirepo.net> - 0.32.1-1
- update to 0.32.1 (no change)

* Fri Oct  4 2019 Remi Collet <remi@remirepo.net> - 0.31.0-1
- update to 0.31.0

* Thu Sep 19 2019 Remi Collet <remi@remirepo.net> - 0.30.2-1
- update to 0.30.2
- add upstream patch for PHP 7.4

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 0.30.0-2
- rebuild for 7.4.0RC1

* Fri Aug  9 2019 Remi Collet <remi@remirepo.net> - 0.30.0-1
- update to 0.30.0

* Wed Jul  3 2019 Remi Collet <remi@remirepo.net> - 0.29.0-1
- update to 0.29.0

* Tue Jun 25 2019 Remi Collet <remi@remirepo.net> - 0.28.1-1
- update to 0.28.1
- update options in provided configuration

* Thu Jun 20 2019 Remi Collet <remi@remirepo.net> - 0.28.0-1
- update to 0.28.0

* Fri Jun  7 2019 Remi Collet <remi@remirepo.net> - 0.27.2-1
- update to 0.27.2

* Thu Jun  6 2019 Remi Collet <remi@remirepo.net> - 0.27.1-1
- update to 0.27.1

* Sat Jun  1 2019 Remi Collet <remi@remirepo.net> - 0.26.0-1
- update to 0.26.0
- drop patch merged upstream

* Mon May 27 2019 Remi Collet <remi@remirepo.net> - 0.23.0-2
- add patch for 7.4 from
  https://github.com/DataDog/dd-trace-php/pull/452

* Fri May 10 2019 Remi Collet <remi@remirepo.net> - 0.23.0-1
- update to 0.23.0 (no change)

* Wed May  8 2019 Remi Collet <remi@remirepo.net> - 0.22.0-1
- update to 0.22.0

* Thu May  2 2019 Remi Collet <remi@remirepo.net> - 0.21.0-1
- update to 0.21.0
- drop patch merged upstream

* Fri Apr 26 2019 Remi Collet <remi@remirepo.net> - 0.20.0-1
- update to 0.20.0
- add patch for test suite on 7.3 from
  https://github.com/DataDog/dd-trace-php/pull/412

* Sun Apr 14 2019 Remi Collet <remi@remirepo.net> - 0.19.0-1
- update to 0.19.0

* Tue Apr  9 2019 Remi Collet <remi@remirepo.net> - 0.18.0-2
- test build

* Tue Apr  9 2019 Remi Collet <remi@remirepo.net> - 0.18.0-1
- update to 0.18.0
- open https://github.com/DataDog/dd-trace-php/issues/393
  missing files in pecl archive, and open
  https://github.com/DataDog/dd-trace-php/pull/397
- open https://github.com/DataDog/dd-trace-php/issues/394
  failed test on 32-bit build
- open https://github.com/DataDog/dd-trace-php/issues/395
  build failure with old GCC, and open
  https://github.com/DataDog/dd-trace-php/pull/396

* Wed Mar 27 2019 Remi Collet <remi@remirepo.net> - 0.17.0-1
- update to 0.17.0 (no change)

* Thu Mar 21 2019 Remi Collet <remi@remirepo.net> - 1.16.1-1
- update to 1.16.1 (no change)

* Wed Mar 20 2019 Remi Collet <remi@remirepo.net> - 0.16.0-1
- update to 0.16.0
- update provided configuration

* Tue Mar 12 2019 Remi Collet <remi@remirepo.net> - 0.15.1-1
- update to 0.15.1 (stable)

* Wed Feb 27 2019 Remi Collet <remi@remirepo.net> - 0.14.1-1
- update to 0.14.1

* Wed Feb 27 2019 Remi Collet <remi@remirepo.net> - 0.14.0-1
- update to 0.14.0
- update provided configuration

* Mon Feb 25 2019 Remi Collet <remi@remirepo.net> - 0.13.4-1
- update to 0.13.4

* Tue Feb 19 2019 Remi Collet <remi@remirepo.net> - 0.13.3-1
- update to 0.13.3

* Tue Feb 19 2019 Remi Collet <remi@remirepo.net> - 0.13.2-1
- update to 0.13.2

* Wed Feb 13 2019 Remi Collet <remi@remirepo.net> - 0.13.1-1
- update to 0.13.1

* Wed Feb 13 2019 Remi Collet <remi@remirepo.net> - 0.13.0-1
- update to 0.13.0

* Sat Feb  2 2019 Remi Collet <remi@remirepo.net> - 0.12.0-1
- update to 0.12.0

* Wed Jan 30 2019 Remi Collet <remi@remirepo.net> - 0.11.0-1
- update to 0.11.0
- open https://github.com/DataDog/dd-trace-php/issues/271 PHP 5 ZTS

* Tue Jan 22 2019 Remi Collet <remi@remirepo.net> - 0.10.0-1
- update to 0.10.0
- open https://github.com/DataDog/dd-trace-php/issues/249 missing files
- open https://github.com/DataDog/dd-trace-php/issues/250 PHP compat
- open https://github.com/DataDog/dd-trace-php/issues/253 PHP 5.4 ZTS

* Sat Jan 12 2019 Remi Collet <remi@remirepo.net> - 0.9.1-1
- update to 0.9.1

* Tue Jan  8 2019 Remi Collet <remi@remirepo.net> - 0.9.0-1
- update to 0.9.0

* Fri Jan  4 2019 Remi Collet <remi@remirepo.net> - 0.8.1-1
- initial package, version 0.8.1 (beta)
- open https://github.com/DataDog/dd-trace-php/issues/213 PHP < 5.6
- open https://github.com/DataDog/dd-trace-php/issues/212 PHP 7.3
